{% extends 'django_spire/base/base.html' %}

{% block base_body_content %}
    {% include 'django_spire/error/error.html' with error_code='500' heading='Something Went Wrong' subheading="Don't Worry, We're Already Working On It!" %}
{% endblock %}