.knowledge-nav-item {
    transition: all 0.10s ease;
    border-radius: 8px;
    padding: 3px 3px;
}

.knowledge-nav-item:hover {
    box-shadow: 0 4px 6px rgba(0, 0, 0, 0.2);
    background-color: var(--app-layer-two);
}
