{% extends 'django_spire/card/title_card.html' %}

{% block card_padding_class %}p-0{% endblock %}

{% block card_title %}
   {{ group.name }} Permissions - {{ group.user_set.count }} Users
{% endblock %}

{% block card_title_content %}
    {% for perm_data in permission_data %}
        {% include 'django_spire/auth/group/item/group_perm_item.html' %}
    {% endfor %}
{% endblock %}
