<ol
    class="breadcrumb small d-none d-lg-flex mb-0 mb-n1"
    style="--bs-breadcrumb-divider: '>';"
>
    {% for breadcrumb in breadcrumbs %}
        <li class="breadcrumb-item">
            {% if breadcrumb.href and forloop.counter != breadcrumb_list|length %}
                <a
                    class="text-decoration-none"
                    href="{{ breadcrumb.href }}"
                >
                    {{ breadcrumb.name }}
                </a>
            {% else %}
                <span>{{ breadcrumb.name }}</span>
            {% endif %}
        </li>
    {% endfor %}
</ol>
