<h2 class="mb-4">Typography</h2>
<div class="row">
    <div class="col-6">
        <h1>Heading 1</h1>
        <h2>Heading 2</h2>
        <h3>Heading 3</h3>
        <h4>Heading 4</h4>
        <h5>Heading 5</h5>
        <h6>Heading 6</h6>
    </div>
    <div class="col-6">
        <div class="fs-1">Font Size 1</div>
        <div class="fs-2">Font Size 2</div>
        <div class="fs-3">Font Size 3</div>
        <div class="fs-4">Font Size 4</div>
        <div class="fs-5">Font Size 5</div>
        <div class="fs-6">Font Size 6</div>
        <div class="fs-0">Font Size 0 (base)</div>
        <div class="fs--1">Font Size --1 (small)</div>
        <div class="fs--2">Font Size --2 (smaller)</div>
        <a href="#">Hyper Link</a>
    </div>
</div>
