<div class="row mt-6 text-center">
    <div class="col h1 fw-bold text-app-danger">
        {{ error_code }}
    </div>
</div>

<div class="row mt-3 mb-3 text-center">
    <div class="col">
        <div class="h5  text-app-primary py-4">
            {{ heading }}
        </div>
        <div class="h6 text-app-secondary pb-5">
            {{ subheading }}
        </div>
    </div>
</div>
