# Generated by Django 5.2.5 on 2025-09-06 00:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_knowledge', '0002_alter_entryversionblock_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='collection',
            name='order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='entry',
            name='order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='entryversionblock',
            name='order',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
