# These imports are for the migrations to work as a single app "django_spire_knowledge"

from django_spire.knowledge.collection.admin import *
from django_spire.knowledge.entry.admin import *
from django_spire.knowledge.entry.version.admin import *
from django_spire.knowledge.entry.version.block.admin import *
