{% extends 'django_spire/theme/card/base_preview_card.html' %}

{% block card_title %}Colors{% endblock %}


{% block card_button %}
    {% url 'django_spire:theme:page:colors' as colors_url %}
    {% include 'django_spire/button/primary_button.html' with button_text='Full Preview' button_href=colors_url %}
{% endblock %}

{% block preview_card_icon %}bi bi-palette{% endblock %}

{% block preview_card_subtitle %}
    Color Palette
{% endblock %}

{% block preview_card_description %}
    Explore the complete color system
{% endblock %}

{% block preview_card_content %}
    <div class="preview-sample">
        <div class="d-flex flex-wrap">
            <!-- Primary colors -->
            <div class="p-2 m-1 bg-app-primary text-white" style="width: 40px; height: 40px;"></div>
            <div class="p-2 m-1 bg-app-primary-soft text-dark" style="width: 40px; height: 40px;"></div>
            <div class="p-2 m-1 bg-app-primary-dark text-white" style="width: 40px; height: 40px;"></div>

            <!-- Secondary colors -->
            <div class="p-2 m-1 bg-app-secondary text-white" style="width: 40px; height: 40px;"></div>
            <div class="p-2 m-1 bg-app-secondary-soft text-dark" style="width: 40px; height: 40px;"></div>
            <div class="p-2 m-1 bg-app-secondary-dark text-white" style="width: 40px; height: 40px;"></div>

            <!-- Accent colors -->
            <div class="p-2 m-1 bg-app-accent text-white" style="width: 40px; height: 40px;"></div>
            <div class="p-2 m-1 bg-app-accent-soft text-dark" style="width: 40px; height: 40px;"></div>
            <div class="p-2 m-1 bg-app-accent-dark text-white" style="width: 40px; height: 40px;"></div>
        </div>
    </div>
{% endblock %}
