{% extends 'django_spire/item/item.html' %}

{% block item_title %}
    {% url 'core_file:demo_detail' pk=demo.pk as demo_detail_url %}
    {% include 'django_spire/element/attribute_element.html' with attribute_href=demo_detail_url attribute_type='Name' attribute_value=demo.name %}
{% endblock %}

{% block item_row_content %}
    <div class="col">
        {% include 'django_spire/element/attribute_element.html' with attribute_type='Description' attribute_value=demo.description %}
    </div>
{% endblock %}

{% block item_button %}
{#    {% include 'django_spire/inventory/element/inventory_item_ellpisis.html' %}#}
{% endblock %}
