{% if ticket.purpose == 'app'  %}
    {% include 'django_spire/badge/accent_badge.html' with badge_text=ticket.get_purpose_display %}
{% elif ticket.purpose == 'comp' %}
    {% include 'django_spire/badge/primary_badge.html' with badge_text=ticket.get_purpose_display %}
{% endif %}